"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const os = __importStar(require("os"));
const Keystore_1 = require("./Keystore");
exports.defaultChattervoxDir = path.join(os.homedir(), '.chattervox');
exports.defaultConfigPath = path.join(exports.defaultChattervoxDir, 'config.json');
exports.defaultKeystorePath = path.join(exports.defaultChattervoxDir, 'keystore.json');
exports.defaultConfig = {
    version: 2,
    callsign: 'N0CALL',
    ssid: 0,
    keystoreFile: exports.defaultKeystorePath,
    kissPort: '/tmp/kisstnc',
    kissBaud: 9600,
};
/** Save a config file as JSON
 * @function save
 * @param  {Config} config
 * @param  {string} configPath?
 * @returns void
 */
function save(config, configPath) {
    const path = typeof configPath === 'string' ? configPath : exports.defaultConfigPath;
    fs.writeFileSync(path, JSON.stringify(config, null, 4));
}
exports.save = save;
/** Load a config file
 * @function load
 * @param  {string} configPath?
 * @returns Config
 */
function load(configPath) {
    const path = typeof configPath === 'string' ? configPath : exports.defaultConfigPath;
    return JSON.parse(fs.readFileSync(path).toString('utf8'));
}
exports.load = load;
/** Check if the config file (or any file) exists
 * @function exists
 * @param  {string} configPath?
 * @returns boolean
 */
function exists(configPath) {
    const path = typeof configPath === 'string' ? configPath : exports.defaultConfigPath;
    return fs.existsSync(path);
}
exports.exists = exists;
/**
 * Create new chattervox directory, config file, and keystore ONLY if they do
 * not already exist.
 * @function init
 */
function init() {
    if (!fs.existsSync(exports.defaultChattervoxDir)) {
        fs.mkdirSync(exports.defaultChattervoxDir);
    }
    if (!exists(exports.defaultConfigPath)) {
        save(exports.defaultConfig);
    }
    if (!exists(exports.defaultKeystorePath)) {
        // simply creating a new keystore object with save the store
        new Keystore_1.Keystore(exports.defaultKeystorePath);
    }
}
exports.init = init;
//# sourceMappingURL=config.js.map